# twinfiles

Command line tool to find and remove duplicate files

![License: MIT](https://img.shields.io/github/license/joaompinto/twinfiles?style=for-the-badge&color=%23007ec6)
[![PyPi](https://img.shields.io/pypi/v/twinfiles.svg?style=for-the-badge&color=%23007ec6)](https://pypi.python.org/pypi/twinfiles)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg?style=for-the-badge)](https://github.com/ambv/black)


<div align="center">

<img src="https://raw.githubusercontent.com/joaompinto/twinfiles/master/imgs/use.png" alt="twinfiles in action" width="100%"/>

</div>

## Motivation

Over the years I have accumulated multiple backups of photos leading to a lot of duplicates. I need an easy way to clean my photos.

## Installation

```bash
pip install twinfiles
```

## Usage

```sh
# To delete add --delete
twinfiles ~/OneDrive
```
